<font size="+1">

AeroMAPS is a framework for performing Multidisciplinary Assessment of Prospective Scenarios for air transport. For 
instance, it allows simulating and analyzing scenarios for reducing aviation climate impacts through various levers of 
action. It is intended to become a sectoral Integrated Assessment Model (IAM) taking into account technological, 
environmental, sociological, economic and other considerations. It aims to assess the sustainability of simulated air 
transport transition scenarios on multiple criteria.

A <u><a href="https://aeromaps.github.io/AeroMAPS/intro.html" target="_blank">documentation</a></u> is available for 
more details on AeroMAPS. More specifically, this website hosts a graphical user interface to facilitate the handling 
of the framework. A dedicated tutorial and the different settings used on this user interface can be directly found 
<u><a href="https://aeromaps.github.io/AeroMAPS/books/documentation_gui.html" target="_blank">here</a></u>.

The source code of AeroMAPS is available on a 
<u><a href="https://github.com/AeroMAPS/AeroMAPS" target="_blank">GitHub repository</a></u>.

AeroMAPS is licensed under the 
<u><a href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GPL-3.0</a></u> license.

</font>